# XOSD-XFT - OSD for X11

Inspired by [libxosd](https://sourceforge.net/projects/libxosd/).

`xosd-xft` supports:

* Use of Xft/TTF fonts
* XRandR and Xinerama extensions
* Allows you to choose a monitor in multihead setups - including active monitor
* Use `osd-echo` to display a [Nerd Font](https://nerdfonts.com) glyph
* Use `osd-cat` to display a file

---

# Building and Installing

GNU Autotools is required for building.

## Arch

To build a package, run this command in the directory containing the PKGBUILD:
```sh
makepkg --syncdeps --install
```

## Manual installation

Instructions may vary depending on your system, but this is a general guideline.

### Installing required packages on Arch-based systems (including Manjaro)

Required dependencies for building:
```sh
sudo pacman -S libxt libxft libxext xorg-util-macros
```

For building with XRandR and Xinerama extensions:
```sh
sudo pacman -S libxrandr libxinerama
```

### Installing required packages on Debian-based systems (including Ubuntu and Linux Mint)

Required packages for building:
```sh
sudo apt-get install libxt-dev libxft-dev libxext-dev xutils-dev
```

XRandR and Xinerama extensions:
```sh
sudo apt-get install libxrandr-dev libxinerama-dev
```

### Installing required packages on RPM-based systems (including Fedora and CentOS)

Required packages for building:
```sh
dnf install libXt-devel libXft-devel libXext-devel xorg-x11-util-macros
```

XRandR and Xinerama extensions:
```sh
dnf install libXrandr libXinerama
```

### Building
From the source directory:
```sh
./autobuild.sh
./configure
make -j$(nproc)
sudo make install
```

---

# Brief Examples

## Using osd-echo

To display volume off glyph and execute `amixer` command:

```sh
    osd-echo -e 'amixer set Master off' :fa-volume_off:
```

To list available glyph names that contain `volume` in them:

```
    osd-echo -lvolume
```

## Using osd-cat

To override the font used to display a file:
```bash
    osd-cat -f "SourceCodePro:size=14" /etc/passwd
```

The following command shows the output of uptime on the screen and updates every 5 seconds:

```bash
while true; do uptime; sleep 5; done | osd-cat --number-of-lines 1 -g 0x1l+0-0
```

## Using the library

```c
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <unistd.h>

#include <xosd-xft.h>

xosd_xft *osd;

int main(int argc, char *argv[])
{
  osd_geometry g;

  xosd_xft *osd = osd_create();
  if(osd_parse_geometry("300x300+0+0*middle/center", "center/middle", &g) == NULL) {
    fprintf(stderr, "%s\n", osd_error);
    return EXIT_FAILURE;
  }
  osd_set_geometry(osd, &g);
  osd_set_font(osd, "mono:size=16");
  osd_set_color(osd, "lightblue", 100);
  osd_set_bgcolor(osd, "black", 100);

  char* message = "HELLO XOSD-XFT" ;
  osd_display(osd, message, strlen(message));

  usleep(1000000);
  osd_destroy(osd);
  return EXIT_SUCCESS;
}
```
